@@ -520,6 +520,7 @@ rdpSettings* freerdp_settings_new(DWORD flags)
 	settings->GfxProgressiveV2 = FALSE;
 	settings->GfxH264 = FALSE;
 	settings->GfxAVC444 = FALSE;
+	settings->GfxSendQoeAck = FALSE;
 	settings->ClientAutoReconnectCookie = (ARC_CS_PRIVATE_PACKET*) calloc(1,
 	                                      sizeof(ARC_CS_PRIVATE_PACKET));
 
@@ -768,8 +769,8 @@ rdpSettings* freerdp_settings_clone(rdpSettings* settings)
 
 		if (_settings->ChannelDefArraySize > 0)
 		{
-			_settings->ChannelDefArray = (CHANNEL_DEF*) malloc(sizeof(
-			                                 CHANNEL_DEF) * settings->ChannelDefArraySize);
+			_settings->ChannelDefArray = (CHANNEL_DEF*) calloc(settings->ChannelDefArraySize,
+									sizeof(CHANNEL_DEF));
 
 			if (!_settings->ChannelDefArray)
 				goto out_fail;
@@ -785,8 +786,8 @@ rdpSettings* freerdp_settings_clone(rdpSettings* settings)
 
 		if (_settings->MonitorDefArraySize > 0)
 		{
-			_settings->MonitorDefArray = (rdpMonitor*) malloc(sizeof(
-			                                 rdpMonitor) * settings->MonitorDefArraySize);
+			_settings->MonitorDefArray = (rdpMonitor*) calloc(settings->MonitorDefArraySize,
+									sizeof(rdpMonitor));
 
 			if (!_settings->MonitorDefArray)
 				goto out_fail;
